@@ -35,7 +35,7 @@ class AutoConvHandler:
 		if not state:
 			state = self.conversation.get_state(self.tData.context.user_data.get(telegram_id).get('state'))
 			if state.list and isinstance(data,int): value = [b for b in reduce(lambda x,y: x+y,self._list_keyboard) if b.callback_data != None and b.callback_data == data][0].text
-			else: value = d if (c := state.callback) and (d := c[0].get(data if not isinstance(data,int) and not data.isdigit() else int(data))) else data
+			else: value = d if (c := state.callback) and (d := c[0].get(data if not isinstance(data,int) and not str(data).isdigit() else int(data))) else data
 			if state != self.conversation.end: self.tData.context.user_data.get(telegram_id).get('data').update({state.name:value})
 			new_state = self._next_state(state,data)
 		else: new_state = state
@@ -74,7 +74,9 @@ class AutoConvHandler:
 		data = self.tData.context.user_data.get(self.tData.update.effective_chat.id)
 		if (state_l := data.get('list')):
 			i = int(data.get('list_i'))
-			new_i = state_l.index(data.get('data').get(state.name)) if state.list_all else (i-1,i+1)[data.get('data').get(state.name) == state.list_buttons[1] or not i]
+			if state.list_all: new_i = state_l.index(data.get('data').get(state.name))
+			elif not state.list_all and data.get('data').get(state.name) not in state.list_buttons: new_i = i
+			else: new_i = (i-1,i+1)[data.get('data').get(state.name) == state.list_buttons[1]]
 			data.update({'list_i':new_i})
 		else:
 			state_l = state.list(self.tData.prepare())
